@@ -30,13 +30,13 @@ class UserPermissionDelegate : public QItemDelegate
     Q_OBJECT
 
 public:
-    UserPermissionDelegate(QObject *parent = 0);
+    explicit UserPermissionDelegate(QObject *parent = nullptr);
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const;
-    void setEditorData(QWidget *editor, const QModelIndex &index) const;
+                          const QModelIndex &index) const override;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
     void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const;
+                      const QModelIndex &index) const override;
 };
 
 #endif
